@@ -70,6 +70,12 @@ class ServiceAgreement(Service):
                              ServiceTypes.NFT_ACCESS,
                              values, ServiceTypesIndices.DEFAULT_NFT721_ACCESS_INDEX)
 
+        elif service_type == ServiceTypes.ASSET_ACCESS_PROOF:
+            values['index'] = ServiceTypesIndices.DEFAULT_ACCESS_PROOF_INDEX
+            Service.__init__(self, service_endpoint,
+                             ServiceTypes.ASSET_ACCESS_PROOF,
+                             values, ServiceTypesIndices.DEFAULT_ACCESS_PROOF_INDEX)
+
         else:
             raise ValueError(f'The service_type {service_type} is not currently supported.')
 
@@ -81,6 +87,22 @@ class ServiceAgreement(Service):
         """
         return int(self.get_param_value_by_name('_numberNfts'))
 
+    def get_key_hash(self):
+        """
+        Return the key hash
+
+        :return: Str
+        """
+        return self.attributes['main']['_hash']
+
+    def get_provider_babyjub_key(self):
+        """
+        Return the provider babyjub key
+
+        :return: Str[]
+        """
+        return self.attributes['main']['_providerPub']
+
     def get_nft_holder(self):
         """
         Return the NFT holder
@@ -312,6 +334,9 @@ class ServiceAgreement(Service):
         if self.type == ServiceTypes.ASSET_ACCESS:
             access_cond_id = self.generate_access_condition_id(keeper, agreement_id, asset_id, consumer_address)
 
+        elif self.type == ServiceTypes.ASSET_ACCESS_PROOF:
+            access_cond_id = self.generate_access_proof_condition_id(keeper, agreement_id, asset_id, consumer_address)
+
         elif self.type == ServiceTypes.CLOUD_COMPUTE:
             access_cond_id = self.generate_compute_condition_id(keeper, agreement_id, asset_id, consumer_address)
 
@@ -343,6 +368,14 @@ class ServiceAgreement(Service):
         return add_0x_prefix(
             keeper.access_condition.contract.functions.generateId(agreement_id, _hash).call().hex())
 
+    def generate_access_proof_condition_id(self, keeper, agreement_id, asset_id, consumer_address):
+        keyhash = self.get_key_hash()
+        provider_address = self.get_provider_babyjub_key()
+        _hash = add_0x_prefix(
+            keeper.access_proof_condition.hash_values(keyhash, consumer_address, provider_address).hex())
+        return add_0x_prefix(
+            keeper.access_proof_condition.contract.functions.generateId(agreement_id, _hash).call().hex())
+
     def generate_nft_access_condition_id(self, keeper, agreement_id, asset_id, consumer_address):
         _hash = add_0x_prefix(
             keeper.nft_access_condition.hash_values(asset_id, consumer_address).hex())
